@@ -2,8 +2,7 @@ import numpy as np
 from sklearn.datasets import load_breast_cancer
 from sklearn.model_selection import KFold
 from sklearn.base import BaseEstimator, ClassifierMixin
-
-from photonai.base import Hyperpipe, PipelineElement, OutputSettings
+from photonai.base import Hyperpipe, PipelineElement
 
 
 class AdditionalDataWrapper(BaseEstimator, ClassifierMixin):
@@ -25,24 +24,17 @@ class AdditionalDataWrapper(BaseEstimator, ClassifierMixin):
         return None
 
 
-# WE USE THE BREAST CANCER SET FROM SKLEARN
-X, y = load_breast_cancer(return_X_y=True)
-
-settings = OutputSettings(project_folder='./tmp/')
-
-# DESIGN YOUR PIPELINE
-my_pipe = Hyperpipe('basic_svm_pipe',
-                    metrics=['accuracy', 'precision', 'recall', 'balanced_accuracy'],  # the performance metrics of your interest
+my_pipe = Hyperpipe('additional_data_pipe',
+                    metrics=['accuracy', 'precision', 'recall', 'balanced_accuracy'],
                     best_config_metric='accuracy',
                     outer_cv=KFold(n_splits=3),
                     inner_cv=KFold(n_splits=3),
                     verbosity=1,
-                    output_settings=settings)
+                    project_folder='./tmp/')
 
 my_pipe.add(PipelineElement('StandardScaler'))
 
-
 my_pipe += PipelineElement.create("CustomWrapper", AdditionalDataWrapper(), hyperparameters={})
 
+X, y = load_breast_cancer(return_X_y=True)
 my_pipe.fit(X, y, true_predictions=np.array(y))
-
