@@ -1,7 +1,7 @@
 from sklearn.datasets import load_iris
 from sklearn.model_selection import KFold
 
-from photonai.base import Hyperpipe, PipelineElement, OutputSettings
+from photonai.base import Hyperpipe, PipelineElement
 from photonai.optimization import FloatRange, Categorical
 
 # loading the iris dataset
@@ -16,7 +16,7 @@ my_pipe = Hyperpipe('multi_class_svm_pipe',
                     outer_cv=KFold(n_splits=3, shuffle=True),
                     inner_cv=KFold(n_splits=3, shuffle=True),
                     verbosity=1,
-                    output_settings=OutputSettings(project_folder='./tmp/'))
+                    project_folder='./tmp/')
 
 
 my_pipe.add(PipelineElement('StandardScaler'))
@@ -27,4 +27,3 @@ my_pipe += PipelineElement('SVC',
                            gamma='scale')
 
 my_pipe.fit(X, y)
-
