@@ -1,26 +1,21 @@
-"""
-Example script for batched elements
-"""
-
 from sklearn.datasets import load_breast_cancer
 from sklearn.model_selection import KFold
 
-from photonai.base import Hyperpipe, PipelineElement, Preprocessing, OutputSettings
+from photonai.base import Hyperpipe, PipelineElement, Preprocessing
 from photonai.optimization import FloatRange, Categorical, IntegerRange
 
 # WE USE THE BREAST CANCER SET FROM SKLEARN
 X, y = load_breast_cancer(return_X_y=True)
 
 # DESIGN YOUR PIPELINE
-settings = OutputSettings(project_folder='./tmp/')
-my_pipe = Hyperpipe('batching',
+my_pipe = Hyperpipe('batching_pipe',
                     optimizer='grid_search',
                     metrics=['accuracy', 'precision', 'recall', 'balanced_accuracy'],
                     best_config_metric='accuracy',
+                    project_folder='./tmp/',
                     outer_cv=KFold(n_splits=3),
                     inner_cv=KFold(n_splits=5),
-                    verbosity=1,
-                    output_settings=settings)
+                    verbosity=0)
 
 
 preprocessing = Preprocessing()
@@ -41,5 +36,3 @@ my_pipe += PipelineElement('SVC', hyperparameters={'kernel': Categorical(['rbf',
 my_pipe.fit(X, y)
 
 debug = True
-
-
