@@ -2,17 +2,17 @@ import numpy as np
 from sklearn.datasets import load_boston
 from sklearn.model_selection import KFold
 
-from photonai.base import Hyperpipe, PipelineElement, OutputSettings
+from photonai.base import Hyperpipe, PipelineElement
 
 X, y = load_boston(return_X_y=True)
 
-my_pipe = Hyperpipe(name='default_pipe',
-                    metrics=['mean_absolute_error', 'mean_squared_error', 'pearson_correlation'],  # the performance metrics of interest
+my_pipe = Hyperpipe(name='single_outer_pipe',
+                    metrics=['mean_absolute_error', 'mean_squared_error', 'pearson_correlation'],
                     best_config_metric='mean_absolute_error',
-                    eval_final_performance=False,
+                    use_test_set=False,
                     inner_cv=KFold(n_splits=10, shuffle=True, random_state=42),
-                    verbosity=2,
-                    output_settings=OutputSettings(plots=False, project_folder='./tmp/'))
+                    verbosity=0,
+                    project_folder='./tmp/')
 
 
 # ADD ELEMENTS TO YOUR PIPELINE
