@@ -1,20 +1,47 @@
 from enum import Enum
 import numpy as np
+import numbers
 import inspect
+import warnings
+
 from photonai.processing.metrics import Scorer
 from photonai.photonlogger.logger import logger
 
 
 class PhotonBaseConstraint:
-    """
-    The PHOTON base interface for any performance constraints that could speed up hyperparameter search.
-    After a particular configuration is tested in one fold, the performance constraint objects are called to
-    evaluate if the configuration is promising. If not, further testing in other folds is skipped to increase speed.
-    """
+    """Photon base constraint.
 
-    ENUM_STRATEGY = Enum("strategy", "first all mean")
+    The PHOTONAI base interface for any performance constraints
+    that could speed up hyperparameter search.
+    After a particular configuration is tested in one fold,
+    the performance constraint objects are called to
+    evaluate if the configuration is promising. If not,
+    further testing in other folds is skipped to increase speed.
 
-    def __init__(self, strategy='first', metric='', threshold: float = None, margin: float = 0, **kwargs):
+    """
+    ENUM_STRATEGY = Enum("strategy", "first any mean")
+
+    def __init__(self, strategy: str = 'first', metric: str = '', threshold: float = None, margin: float = 0, **kwargs):
+        """
+        Initialize the object.
+
+        Parameters:
+            strategy:
+                One of [first, all, mean].
+
+            metric:
+                Name of metric to perform on.
+
+            threshold:
+                Limit for decision.
+
+            margin:
+                Value to be added for threshold value.
+                Continue if:
+                - Scorer: P(Config) > P(Dummy) + margin
+                - Error:  P(Config) < P(Dummy) - margin
+
+        """
         self._metric = None
         self._greater_is_better = None
         self._strategy = None
@@ -23,23 +50,20 @@ class PhotonBaseConstraint:
         self.metric = metric
         self.threshold = threshold
         self.margin = margin
+
+        if not isinstance(self.margin, numbers.Number):
+            msg = "Could not set margin in {}. Defaulting to 0.".format(str(type(self).__name__))
+            logger.warning(msg)
+            warnings.warn(msg)
+            self.margin = 0
         self.strategy = strategy
 
     @property
     def strategy(self):
-        """
-        Getter for attribute strategy.
-        :return:
-        """
         return self._strategy
 
     @strategy.setter
     def strategy(self, value):
-        """
-        Setter for strategy. Checks if strategy is supported.
-        :param value: String
-        :return:
-        """
         try:
             self._strategy = PhotonBaseConstraint.ENUM_STRATEGY[value]
         except KeyError:
@@ -48,19 +72,10 @@ class PhotonBaseConstraint:
 
     @property
     def metric(self):
-        """
-        Getter for attribute metric.
-        :return:
-        """
         return self._metric
 
     @metric.setter
     def metric(self, value):
-        """
-        Setter for attribute metric.
-        :param value: metric value
-        :return:
-        """
         try:
             self._metric = value
             self._greater_is_better = Scorer.greater_is_better_distinction(self._metric)
@@ -69,31 +84,44 @@ class PhotonBaseConstraint:
             logger.warning("Your metric is not supported. Performance constraints are constantly False.")
 
     def shall_continue(self, config_item):
-        """
-        Function to evaluate if the constraint is reached.
+        """Function to evaluate if the constraint is reached.
+
         If it returns True, the testing of the configuration is continued.
         If it returns False, further testing of the configuration is skipped
         to increase speed of the hyperparameter search.
 
-        Parameters
-        ----------
-        * 'config_item' [MDBConfig]:
-            All performance metrics and other scoring information for all configuration's performance.
-            Can be used to evaluate if the configuration has any potential to serve the model's learning task.
+        Parameters:
+            config_item:
+                All performance metrics and other scoring information
+                for all configuration's performance.
+                Can be used to evaluate if the configuration has any potential
+                to serve the model's learning task.
+
         """
         if self.metric == "unknown":
-            logger.warning("The metric is not known. Please check the metric: " + self.metric + ". " +
-                        "Performance constraints are constantly True.")
+            msg = "The metric is not known. Please check the metric: {}. " \
+                  "Performance constraints are constantly True.".format(self.metric)
+            logger.warning(msg)
+            warnings.warn(msg)
             return True
         if self.metric not in config_item.inner_folds[0].validation.metrics:
-            logger.warning("The metric is not calculated. Please insert " + self.metric + " to Hyperpipe.metrics. " +
-                        "Performance constraints are constantly False.")
+            msg = "The metric is not calculated. Please insert to Hyperpipe.metrics. " \
+                  "Performance constraints are constantly False.".format(self.metric)
+            logger.warning(msg)
+            warnings.warn(msg)
             return False
+        if self.threshold is None:
+            msg = "Could not established threshold for performance constraint: {}. " \
+                  "Continuing computation for all folds.".format(str(type(self).__name__))
+            logger.warning(msg)
+            warnings.warn(msg)
+            return True
+
         if self._greater_is_better:
             if self.strategy.name == 'first':
                 if config_item.inner_folds[0].validation.metrics[self.metric] < self.threshold:
                     return False
-            elif self.strategy.name == 'all':
+            elif self.strategy.name == 'any':
                 if any(item < self.threshold for item in [x.validation.metrics[self.metric]
                                                           for x in config_item.inner_folds]):
                     return False
@@ -105,7 +133,7 @@ class PhotonBaseConstraint:
             if self.strategy.name == 'first':
                 if config_item.inner_folds[0].validation.metrics[self.metric] > self.threshold:
                     return False
-            elif self.strategy.name == 'all':
+            elif self.strategy.name == 'any':
                 if any(item > self.threshold for item in [x.validation.metrics[self.metric]
                                                           for x in config_item.inner_folds]):
                     return False
@@ -115,10 +143,6 @@ class PhotonBaseConstraint:
             return True
 
     def copy_me(self):
-        """
-        Copy self object.
-        :return:
-        """
         new_me = type(self)(metric=self.metric)
         signature = inspect.getfullargspec(self.__init__)[0]
         for attr in signature:
@@ -129,91 +153,143 @@ class PhotonBaseConstraint:
         return new_me
 
 
-class MinimumPerformance(PhotonBaseConstraint):
+class MinimumPerformanceConstraint(PhotonBaseConstraint):
+    """Minumum performance.
+
+    Tests if a configuration performs better than a given limit for a particular metric.
+
+    Examples:
+        MinimumPerformance('accuracy', 0.96) tests if the configuration
+        has at least a performance of 0.96 in
+        (the) [first, all, mean] fold(s).
+        If not further testing of the configuration is skipped,
+        as it is regarded as not promising enough.
+
+    """
+    def __init__(self, metric: str = '', threshold: float = 1., strategy: str = 'first'):
+        """
+        Initialize the object.
+
+        Parameters:
+            metric:
+                Name of metric to perform on.
+
+            threshold:
+                Limit for the decision.
+
+            strategy:
+                One of [first, all, mean].
+
+        """
+        super(MinimumPerformanceConstraint, self).__init__(strategy=strategy, metric=metric, threshold=threshold)
+
+
+class DummyPerformanceConstraint(PhotonBaseConstraint):
     """
     Tests if a configuration performs better than a given limit for a particular metric.
 
-    Example
-    -------
-    MinimumPerformance('accuracy', 0.96) tests if the configuration has at least a performance of 0.96 in
-    (the) [first, all, mean] fold(s).
-    If not further testing of the configuration is skipped, as it is regarded as not promising enough.
+
+    Examples:
+        DummyPerformance('accuracy', 0.1) tests if the configuration has
+        at least a 10% better performance than the dummy
+        estimator. Distinguish between [first, all, mean] fold(s).
+        If not further testing of the configuration is skipped,
+        as it is regarded as not promising enough.
+
     """
 
-    def __init__(self, metric: str = '', threshold: float = 1., strategy='first'):
-        super(MinimumPerformance, self).__init__(strategy=strategy, metric=metric, threshold=threshold)
+    def __init__(self, metric: str = '', margin: float = 0, strategy: str = 'first'):
+        """
+        Initialize the object.
 
+        Parameters:
+            metric:
+                Name of metric to perform on.
 
-class DummyPerformance(PhotonBaseConstraint):
-    """
-    Tests if a configuration performs better than a given limit for a particular metric.
+            margin:
+                Value to be added for threshold value.
+                Continue if:
+                - Scorer: P(Config) > P(Dummy) + margin
+                - Error:  P(Config) < P(Dummy) - margin
 
-    Example
-    -------
-    DummyPerformance('accuracy', 0.1) tests if the configuration has at least a 10% better performance than the dummy
-    estimator. Distinguish between [first, all, mean] fold(s).
-    If not further testing of the configuration is skipped, as it is regarded as not promising enough.
-    """
+            strategy:
+                One of [first, all, mean].
 
-    def __init__(self, metric: str = '', margin: float = 0, strategy='first'):
-        super(DummyPerformance, self).__init__(strategy=strategy, metric=metric, margin=margin)
+        """
+        super(DummyPerformanceConstraint, self).__init__(strategy=strategy, metric=metric, margin=margin)
 
     def set_dummy_performance(self, dummy_result):
+        """Set threshold with margin and dummy_performance value.
+        At the time the object is created, this value is not known.
         """
-        Set threshold with margin and dummy_performance value
-        :param dummy_result: MDBScoreInformation type
-        :return:
-        """
-        self.threshold = dummy_result.validation.metrics[self.metric] + self.margin
+        performance = dummy_result.validation.metrics[self.metric]
+        if performance is None or performance is np.nan:
+            raise ValueError("Could not set dummy threshold for metric " + self.metric)
+        if self._greater_is_better:
+            self.threshold = performance + self.margin
+        else:
+            self.threshold = performance - self.margin
 
     def copy_me(self):
-        """
-        Copy self object. Appending threshold to super.copy_me().
-        :return: DummyPerformance
-        """
-        new_me = super(DummyPerformance, self).copy_me()
+        """Copy self object. Appending threshold to super.copy_me()."""
+        new_me = super(DummyPerformanceConstraint, self).copy_me()
         if "threshold" in self.__dict__.keys():
             new_me.threshold = self.threshold
         return new_me
 
 
-class BestPerformance(PhotonBaseConstraint):
+class BestPerformanceConstraint(PhotonBaseConstraint):
     """
     BestPerformance decides in every fold: challenger works better than incumbent
     true: eval next fold, false: eval next config
     better in all inner_folds: incumbent = challenger.
-    """
 
-    def __init__(self, metric: str = '', strategy: str = 'mean'):
+    """
+    def __init__(self, metric: str = '', margin: float = 0, strategy: str = 'mean'):
         """
-        :param metric:
-        :param strategy:
-        :param fold_start:
+        Initialize the object.
+
+        Parameters:
+            metric:
+                Name of metric to perform on.
+
+            margin:
+                Value to be added for threshold value.
+                Continue if:
+                - Scorer: P(Config) > P(Dummy) + margin
+                - Error:  P(Config) < P(Dummy) - margin
+
+            strategy:
+                One of [first, all, mean].
+
         """
-        super(BestPerformance, self).__init__(strategy=strategy, metric=metric)
+        super(BestPerformanceConstraint, self).__init__(strategy=strategy, margin=margin, metric=metric)
+
         self.threshold = None
         self.config_items = {}
         self.required_folds = 0
         self.run = 0
 
     def shall_continue(self, config_item):
-        """
-        Function to evaluate if the constraint is reached.
+        """Function to evaluate if the constraint is reached.
+
         If it returns True, the testing of the configuration is continued.
         If it returns False, further testing of the configuration is skipped
         to increase speed of the hyperparameter search.
 
-        Parameters
-        ----------
-        * 'config_item' [MDBConfig]:
-            All performance metrics and other scoring information for all configuration's performance.
-            Can be used to evaluate if the configuration has any potential to serve the model's learning task.
+        Parameters:
+            config_item:
+                All performance metrics and other scoring information
+                for all configuration's performance.
+                Can be used to evaluate if the configuration has any potential
+                to serve the model's learning task.
+
         """
         self.required_folds = max(self.required_folds, len(self.eval_config_entries(config_item)))
         self.config_items[str(config_item.config_dict)] = self.eval_config_entries(config_item)
 
         # first run default 10 configs
-        if self.run < 10 * self.required_folds -1:
+        if self.run < 10 * self.required_folds - 1:
             self.run += 1
             return True
 
@@ -225,7 +301,7 @@ class BestPerformance(PhotonBaseConstraint):
                 self.threshold = min([np.mean(x) for x in self.config_items.values()])
 
         # calc std between inner_folds and average it over all configs [std only for multiple-run-configs]
-        std = np.mean([np.std(x) for x in self.config_items.values() if len(self.config_items.values())>1])
+        std = np.mean([np.std(x) for x in self.config_items.values() if len(self.config_items.values()) > 1])
         challenger = self.eval_config_entries(config_item)
         if self._greater_is_better:
             if np.mean(challenger) > self.threshold - std:
@@ -240,11 +316,8 @@ class BestPerformance(PhotonBaseConstraint):
         return False
 
     def copy_me(self):
-        """
-        Copy self object. Appending threshold to super.copy_me().
-        :return: BestPerformance
-        """
-        new_me = super(BestPerformance, self).copy_me()
+        """Copy self object. Appending threshold to super.copy_me()."""
+        new_me = super(BestPerformanceConstraint, self).copy_me()
         if "threshold" in self.__dict__.keys():
             new_me.threshold = self.threshold
         return new_me
